nonsequitur.py
==============

A Python module for generating non sequitur text.

Available functions
-------------------

america_russia()
bar()
chicken()
cows()
knock_knock()
lightbulb()
violas()

License
-------

This port inherits Tracery's original Apache License 2.0.

::
    Copyright 2017 Aaron Montoya-Moraga
    Based on code by Kate Compton and Allison Parrish

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
